@@ -1,11 +1,13 @@
-from .utils import TestCase
+import sys
+
 from confetti import Config
 from slash import plugins
 from slash._compat import cStringIO
-from slash.utils import conf_utils
-from slash.utils import cli_utils
 from slash.plugins import PluginInterface
-import sys
+from slash.utils import cli_utils, conf_utils
+
+from .utils import TestCase
+
 
 class OutputCaptureTest(TestCase):
     def setUp(self):
@@ -22,29 +24,50 @@ class ArgumentParsingTest(OutputCaptureTest):
             "a": {"a1": {"flag1": True // conf_utils.Cmdline(off="--no-flag1")}},
             "b": {"b1": {"flag2": False // conf_utils.Cmdline(on="--flag2")}},
             "string_value" : "",
-            "int_value" : 0,
+            "int_value" : 0 // conf_utils.Cmdline(increase="--increase", decrease="--decrease"),
+            "arg_value": "" // conf_utils.Cmdline(arg="--arg-value"),
+            "list": ["existing_item"] // conf_utils.Cmdline(append="--append"),
             })
 
+    def _cli(self, argv):
+        return cli_utils.get_cli_environment_context(argv=argv, config=self.config)
+
+    def test_config_arg_flag(self):
+        with self._cli(["--arg-value=x"]):
+            self.assertEquals(self.config["arg_value"], "x")
+
+    def test_config_increase(self):
+        with self._cli(["--increase"]):
+            self.assertEquals(self.config["int_value"], 1)
+
+    def test_config_decrease(self):
+        with self._cli(["--decrease"]):
+            self.assertEquals(self.config["int_value"], -1)
+
+
     def test_config_off_flag(self):
-        with cli_utils.get_cli_environment_context(argv=["--no-flag1"], config=self.config):
+        with self._cli(["--no-flag1"]):
             self.assertFalse(self.config["a"]["a1"]["flag1"])
         self.assertTrue(self.config["a"]["a1"]["flag1"])
 
     def test_config_on_flag(self):
-        with cli_utils.get_cli_environment_context(argv=["--flag2"], config=self.config):
+        with self._cli(["--flag2"]):
             self.assertTrue(self.config["b"]["b1"]["flag2"])
         self.assertFalse(self.config["b"]["b1"]["flag2"])
 
+    def test_config_append_flag(self):
+        with self._cli(["--append", "a", "--append=b"]):
+            self.assertEquals(self.config["list"], ["existing_item", "a", "b"])
+
     def test_config_assign_flag(self):
-        with cli_utils.get_cli_environment_context(argv=["-o", "string_value=hello", "-o", "int_value=666"], config=self.config):
+        with self._cli(["-o", "string_value=hello", "-o", "int_value=666"]):
             self.assertEquals(self.config.root.string_value, "hello")
             self.assertEquals(self.config.root.int_value, 666)
 
     def test_config_assign_wrong_path_restores_config(self):
         "Given a bad override, the get_parsed_config_args_context() should leave the configuration untouched"
         with self.assertRaises(SystemExit) as caught:
-            with cli_utils.get_cli_environment_context(argv=["-o", "string_value=bla", "-o", "int_value=hello"],
-                                                       config=self.config):
+            with self._cli(["-o", "string_value=bla", "-o", "int_value=hello"]):
                 pass
         self.assertNotEquals(caught.exception.code, 0)
         self.assertEquals(self.config.root.int_value, 0)
